PyUPC-EAN
======

*Python Barcode Library*

PyUPC-EAN is a barcode library/module for Python. It supports the barcode formats upc-e, upc-a, ean-13, ean-8, ean-2, ean-5, itf14, codabar, code11, code39, code93, and msi.

.. image:: https://api.travis-ci.org/GameMaker2k/PyUPC-EAN.svg?branch=master
    :target: https://travis-ci.org/GameMaker2k/PyUPC-EAN
    :alt: Travis CI build status

.. image:: https://img.shields.io/pypi/v/PyUPC-EAN.png
    :target: https://pypi.python.org/pypi/PyUPC-EAN/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/PyUPC-EAN.png
    :target: https://pypi.python.org/pypi/PyUPC-EAN/
    :alt: Number of PyPI downloads

.. image:: https://coveralls.io/repos/GameMaker2k/PyUPC-EAN/badge.png?branch=master
    :target: https://coveralls.io/r/GameMaker2k/PyUPC-EAN?branch=master
    :alt: Code coverage

.. image:: https://landscape.io/github/GameMaker2k/PyUPC-EAN/master/landscape.png
    :target: https://landscape.io/github/GameMaker2k/PyUPC-EAN/master
    :alt: Code health

.. image:: https://www.openhub.net/p/PyUPC-EAN/widgets/project_thin_badge.gif
    :target: https://www.openhub.net/p/PyUPC-EAN
    :alt: Project stats

.. image:: https://drone.io/github.com/GameMaker2k/PyUPC-EAN/status.png
    :target: https://drone.io/github.com/GameMaker2k/PyUPC-EAN/latest
    :alt: Build status

.. image:: https://www.codacy.com/project/badge/711c4c045f1347709dc5dbbcf686e434
    :target: https://www.codacy.com/public/kazukiprzyborowski/PyUPC-EAN
    :alt: Codacy badge
